This function checks the specification of the exposure in function FormalEstmed
specified by users.
The name of exposure specified in function FormalEstmed should be a character.
The exposure should be a numeric and binary factor, otherwise this function warns.
This is an internal function, automatically called by the function FormalEstmed.
confirmingX (X)No return value, called for checking the exposure's name.
a character variable of the exposure's name.