Learn R Programming

unvs.med (version 1.1.0)

ident_Y_type: Identification of Outcome's type

Description

This function identifies the outcome's type according to the model if the user does not directly specify it. The type of outcome could be 'ordinal' or any other characters, e.g., 'non-ordinal'.

This is an internal function, automatically called by the function FormalEstmed.

Usage

ident_Y_type (Y, data)

Value

This function returns a character as the outcome's type.

Arguments

Y

a character variable of the outcome's name.

data

a dataframe used in the analysis.